@@ -39,6 +39,7 @@ def initialize_flake8_plugin(project):
     project.set_property("flake8_max_line_length", 120)
     project.set_property("flake8_exclude_patterns", None)
     project.set_property("flake8_include_test_sources", False)
+    project.set_property("flake8_include_scripts", False)
 
 
 @after("prepare")
@@ -66,8 +67,11 @@ def analyze(project, logger):
     command.use_argument('--exclude={0}').formatted_with_truthy_property('flake8_exclude_patterns')
 
     include_test_sources = project.get_property("flake8_include_test_sources")
+    include_scripts = project.get_property("flake8_include_scripts")
 
-    result = command.run_on_production_source_files(logger, include_test_sources=include_test_sources)
+    result = command.run_on_production_source_files(logger,
+                                                    include_test_sources=include_test_sources,
+                                                    include_scripts=include_scripts)
 
     count_of_warnings = len(result.report_lines)
     count_of_errors = len(result.error_report_lines)
